##  Evaluate Business Criticality and Functional Fit
Before focusing on IT components, understand the importance of each application to the business and assess how well it aligns with current functional requirements. This helps you prioritize applications for mitigation efforts, allowing you to concentrate on the most critical applications first.
Ensure that the evaluation of business criticality and functional fit of your applications is kept current in application fact sheets. Use surveys, to-dos, and Excel import features for effective collaboration and data collection from relevant stakeholders.
![Capturing Business Criticality and Functional Fit in Application Fact Sheets](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275693d67a4410148dded682e032f491_LowRes.png)
Capturing Business Criticality and Functional Fit in Application Fact Sheets
You can also use surveys to ask relevant application owners to assess both the functional fit and business criticality of applications. SAP LeanIX offers free survey templates that you can download from the store and use to collect the required information. To learn more, see [Creating a Survey](https://help.sap.com/docs/leanix/ea/creating-survey?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create surveys, from defining the scope and designing questions to using advanced fields and templates. Learn how to make questions mandatory, add links and descriptions, and import/export surveys.").
The relevant survey templates are:
  * [Application Rationalization (TIME)![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.leanix.net%2Fen%2Fdetails%2Fsurvey%2F01e1c6f0-5a1a-4705-9a0a-0f407c4ac9a0%2F34c6f24c-d7ee-4ea4-93e0-87ca49c01349 "https://store.leanix.net/en/details/survey/01e1c6f0-5a1a-4705-9a0a-0f407c4ac9a0/34c6f24c-d7ee-4ea4-93e0-87ca49c01349"): for collecting functional fit information.
  * [Business Application Criticality Assessment![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.leanix.net%2Fen%2Fdetails%2Fsurvey%2Fa2d31314-c1ef-47de-bff2-6f2c8c996fc0%2F68adac9e-7618-4718-b7ae-542cc2f40f4d "https://store.leanix.net/en/details/survey/a2d31314-c1ef-47de-bff2-6f2c8c996fc0/68adac9e-7618-4718-b7ae-542cc2f40f4d"): for assessing the business criticality of applications.
